/**
  ******************************************************************************
  * @file    Project/STM32F2xx_StdPeriph_Template/main.c 
  * @author  MCD Application Team
  * @version V0.0.3
  * @date    10/15/2010
  * @brief   Main program body
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2010 STMicroelectronics</center></h2>
  */ 

/* Includes ------------------------------------------------------------------*/
#include <stdio.h>
#include <string.h>
#include <yfuns.h>
#include "includes.h"

#define DLY_100US  1000

Int32U CriticalSecCntr;
/** @addtogroup Template_Project
  * @{
  */

/* Private typedef -----------------------------------------------------------*/

/* Private define ------------------------------------------------------------*/

/* Private macro -------------------------------------------------------------*/

/* Private variables ---------------------------------------------------------*/

RCC_ClocksTypeDef RCC_Clocks;

/* Private function prototypes -----------------------------------------------*/
void DelayResolution100us(Int32U Dly);
void SysTickStart(uint32_t Tick);
void SysTickStop(void);
void HardwareInit (void);

/* Private functions ---------------------------------------------------------*/

/*************************************************************************
 * Function Name: DelayResolution100us
 * Parameters: Int32U Dly
 *
 * Return: none
 *
 * Description: Delay ~ (arg * 100us)
 *
 *************************************************************************/
void DelayResolution100us(Int32U Dly)
{
  for(; Dly; Dly--)
  {
    for(volatile Int32U j = DLY_100US; j; j--)
    {
    }
  }
}

void SysTickStart(uint32_t Tick)
{
RCC_ClocksTypeDef Clocks;
volatile uint32_t dummy;

  RCC_GetClocksFreq(&Clocks);

  dummy = SysTick->CTRL;  
  SysTick->LOAD = (Clocks.HCLK_Frequency/8)/Tick;
  
  SysTick->CTRL = 1;
}

void SysTickStop(void)
{
    SysTick->CTRL = 0;
}



void HardwareInit (void)
{
  STM_EVAL_LEDInit (LED1);
  STM_EVAL_PBInit (BUTTON_WAKEUP, BUTTON_MODE_GPIO);
}



/************************************************************************
Simple demo project for Olimex STM32-H407 board
Using the WAKEUP button you can toggle among the different demos:
0) RTC and LED demo:
  The green LED should blink with a ~1 sec period.
1/2) USB OTG/Host demo:
  The mouse cursor should move describing a square.
3) SD card demo:
  - if SD card is presented the green LED is flashing;
  - otherwise the LED is ON.
If you use the WAKEUP button again it will start from demo 0.
************************************************************************/


void main(void)
{
  while (1)
  {
  SystemInit();
  HardwareInit ();
  for(Int32U i = 0;sizeof(Demo)/sizeof(struct s_Demo) > i; i++)
    {  
      (Demo[i].Demo)();
      SysTickStop();
      
      STM_EVAL_GPIOReset();
      
      RCC_AHB1PeriphClockCmd(0x7E6411FF & ~(RCC_AHB1Periph_BKPSRAM | EVAL_COM1_TX_GPIO_CLK | EVAL_COM1_RX_GPIO_CLK), DISABLE);
      RCC_AHB1PeriphResetCmd(0x226011FF & ~(RCC_AHB1Periph_BKPSRAM | EVAL_COM1_TX_GPIO_CLK | EVAL_COM1_RX_GPIO_CLK), ENABLE);
      RCC_AHB1PeriphResetCmd(0x226011FF & ~(RCC_AHB1Periph_BKPSRAM | EVAL_COM1_TX_GPIO_CLK | EVAL_COM1_RX_GPIO_CLK), DISABLE);
  
      RCC_AHB2PeriphClockCmd(0x000000F1 , DISABLE);
      RCC_AHB2PeriphResetCmd(0x000000F1 , ENABLE);
      RCC_AHB2PeriphResetCmd(0x000000F1 , DISABLE);
  
      RCC_APB1PeriphClockCmd(0x36FEC9FF , DISABLE);
      RCC_APB1PeriphResetCmd(0x226011FF , ENABLE);
      RCC_APB1PeriphResetCmd(0x226011FF , DISABLE);
      
      RCC_APB2PeriphClockCmd(0x00075F33 & ~(EVAL_COM1_CLK), DISABLE);
      RCC_APB2PeriphResetCmd(0x00075933 & ~(EVAL_COM1_CLK), ENABLE);
      RCC_APB2PeriphResetCmd(0x00075933 & ~(EVAL_COM1_CLK), DISABLE);
    }
  }
}

/******************* (C) COPYRIGHT 2010 STMicroelectronics *****END OF FILE****/
